/*
    kmgroupware.h

    This file is part of KMail.

    Copyright (c) 2003 - 2004 Bo Thorsen <bo@klaralvdalens-datakonsult.se>
    Copyright (c) 2002 Karl-Heinz Zimmer <khz@klaralvdalens-datakonsult.se>
    Copyright (c) 2003 Steffen Hansen <steffen@klaralvdalens-datakonsult.se>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#ifndef KMGROUPWARE_H
#define KMGROUPWARE_H

#include <qguardedptr.h>

class KMAccount;
class KMMessage;
class KMMainWidget;
class KURL;


class KMGroupware : public QObject
{
  Q_OBJECT

public:
  KMGroupware( QObject* parent = 0, const char* name = 0 );
  ~KMGroupware();

  bool isEnabled() const { return mUseGroupware; }

  /**
     Retrieve matching body part (either text/vCal (or vCard) or
     application/ms-tnef) and decode it.

     If return value is true, s holds a readable vPart.
  */
  static bool vPartFoundAndDecoded( KMMessage* msg, QString& s );

  // functions to be called by KMReaderWin for 'print formatting'
  QString vPartToHTML( const QString& iCal );
  QString msTNEFToHTML( const QByteArray& tnef );

  /**
     KMReaderWin calls this with a URL. Return true if a groupware
     url was handled.
  */
  bool handleLink( const KURL &aUrl, KMMessage* msg );

public slots:
  /* (Re-)Read configuration file */
  void readConfig();

private slots:
  void unregisteredFromDCOP( const QCString& );

private:
  bool mUseGroupware;
};


#endif /* KMGROUPWARE_H */
